polyfemos.almanac.timer — polyfemos 0.3.29 documentation

# polyfemos.almanac.timer

Timing utility classes for debugging

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.almanac.timer.` `timed`(timer)
  Parameters

    timer (`Timer`) – a timer to be used to time the decorated function

  Return type

    func

  Returns

    a decorator to time function execution

Classes

`Timer`([name]) | Timer class
`Timers`(N) | A class to handle multiple timers